==> okteta-0.25.1.tar.xz: okteta-0.25.1/core/piecetable/tests/testpiecetablechangeabstractpiecetablechangeiftest.h <==
/*
    This file is part of the Okteta Core library, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef TESTPIECETABLECHANGEABSTRACTPIECETABLECHANGEIFTEST_H
#define TESTPIECETABLECHANGEABSTRACTPIECETABLECHANGEIFTEST_H

// test
#include "abstractpiecetablechangeiftest.h"

namespace KPieceTable {

class TestPieceTableChangeAbstractPieceTableChangeIfTest : public AbstractPieceTableChangeIfTest
{
    Q_OBJECT

protected: // AbstractPieceTableChangeIfTest API
    AbstractPieceTableChange* createPieceTableChange() override;
    void deletePieceTableChange(AbstractPieceTableChange* pieceTableChange) override;
    void changePieceTable(PieceTable* pieceTable) override;
};

}

#endif

==> okteta-16.12.3.tar.xz: okteta-16.12.3/core/piecetable/tests/testpiecetablechangeabstractpiecetablechangeiftest.h <==
/*
    This file is part of the Okteta Core library, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef TESTPIECETABLECHANGEABSTRACTPIECETABLECHANGEIFTEST_H
#define TESTPIECETABLECHANGEABSTRACTPIECETABLECHANGEIFTEST_H


// test
#include "abstractpiecetablechangeiftest.h"

namespace KPieceTable
{

class TestPieceTableChangeAbstractPieceTableChangeIfTest : public AbstractPieceTableChangeIfTest
{
  protected: // AbstractPieceTableChangeIfTest API
    virtual AbstractPieceTableChange *createPieceTableChange();
    virtual void deletePieceTableChange( AbstractPieceTableChange *pieceTableChange );
    virtual void changePieceTable( PieceTable *pieceTable );
};

}

#endif
